@@ -9,34 +9,17 @@ from uuid import uuid4
 from .utils import api_exception_handler
 
 # providers
-from pytgpt.leo import LEO
-from pytgpt.opengpt import OPENGPT
-from pytgpt.koboldai import KOBOLDAI
-from pytgpt.phind import PHIND
-from pytgpt.llama2 import LLAMA2
-from pytgpt.blackboxai import BLACKBOXAI
-from pytgpt.perplexity import PERPLEXITY
-from pytgpt.yepchat import YEPCHAT
-from pytgpt.gpt4free import GPT4FREE
-from pytgpt.auto import AUTO
-from pytgpt.imager import Imager
-from pytgpt.imager import Prodia
+from pytgpt.gpt4free import AsyncGPT4FREE
+from pytgpt.auto import AsyncAUTO
+from pytgpt.imager import AsyncImager
+from pytgpt.imager import AsyncProdia
 from pytgpt.utils import Audio
+from pytgpt.async_providers import tgpt_mapper as provider_map
 from pytgpt.utils import api_static_image_dir
 
-provider_map = {
-    "leo": LEO,
-    "opengpt": OPENGPT,
-    "koboldai": KOBOLDAI,
-    "phind": PHIND,
-    "llama2": LLAMA2,
-    "blackboxai": BLACKBOXAI,
-    "perplexity": PERPLEXITY,
-    "yepchat": YEPCHAT,
-    "auto": AUTO,
-}
+provider_map.update({"auto": AsyncAUTO})
 
-image_providers = {"default": Imager, "prodia": Prodia}
+image_providers = {"default": AsyncImager, "prodia": AsyncProdia}
 
 supported_providers = list(provider_map.keys()) + gpt4free_providers
 
@@ -51,11 +34,15 @@ class ProvidersModel(BaseModel):
         "json_schema_extra": {
             "examples": [
                 {
-                    "tgpt": ["phind", "opengpt", "koboldai"],
+                    "tgpt": [
+                        "phind",
+                        "opengpt",
+                        "koboldai",
+                    ],
                     "g4f": [
                         "Koala",
-                        "FreeGPT",
-                        "You",
+                        "Blackbox",
+                        "FreeChatgpt",
                     ],
                 }
             ]
@@ -150,7 +137,7 @@ class ImagePayload(BaseModel):
     amount: PositiveInt = 1
     proxy: Union[dict[str, str], None] = None
     timeout: PositiveInt = 30
-    provider: Union[str, None] = None
+    provider: Union[str, None] = "default"
 
     model_config = {
         "json_schema_extra": {
@@ -188,7 +175,8 @@ class ImagePayload(BaseModel):
 
     @validator("provider")
     def validate_provider(provider: Union[str, None]) -> str:
-        if provider not in image_providers:
+
+        if provider is not None and not provider in image_providers:
             raise HTTPException(
                 status_code=status.HTTP_400_BAD_REQUEST,
                 detail=dict(
@@ -202,7 +190,7 @@ class ImageBytesPayload(BaseModel):
     prompt: str
     proxy: Union[dict[str, str], None] = None
     timeout: PositiveInt = 30
-    provider: Union[str, None] = None
+    provider: Union[str, None] = "default"
 
     model_config = {
         "json_schema_extra": {
@@ -223,7 +211,7 @@ class ImageBytesPayload(BaseModel):
 
     @validator("provider")
     def validate_provider(provider: Union[str, None]) -> str:
-        if provider not in image_providers:
+        if provider is not None and not provider in image_providers:
             raise HTTPException(
                 status_code=status.HTTP_400_BAD_REQUEST,
                 detail=dict(
@@ -260,14 +248,14 @@ class ImageResponse(BaseModel):
 
 class TextToAudioPayload(BaseModel):
     message: str
-    voice: Union[str, None] = "Brian"
+    voice: Union[str, None] = "en-US-Wavenet-C"
     proxy: Union[dict[str, str], None] = None
     timeout: int = 30
     model_config = {
         "json_schema_extra": {
             "example": {
                 "message": "There is a place for people like you.",
-                "voice": "Brian",
+                "voice": "en-US-Wavenet-C",
                 "proxy": {
                     "http": "socks4://199.229.254.129:4145",
                     "https": "socks4://199.229.254.129:4145",
@@ -286,7 +274,7 @@ class TextToAudioPayload(BaseModel):
                     message=f"Voice '{voice}' is not one of '[{', '.join(Audio.all_voices)}]"
                 ),
             )
-        return "Brian" if not voice else voice
+        return "en-US-Wavenet-C" if not voice else voice
 
 
 class TextToAudioResponse(BaseModel):
@@ -306,7 +294,7 @@ class TextToAudioResponse(BaseModel):
 
 
 def init_provider(payload: TextGenerationPayload) -> object:
-    return provider_map.get(payload.provider, GPT4FREE)(
+    return provider_map.get(payload.provider, AsyncAUTO)(
         is_conversation=False,  # payload.is_conversation,
         max_tokens=payload.max_tokens,
         timeout=payload.timeout,
@@ -344,8 +332,8 @@ async def non_stream(payload: TextGenerationPayload) -> ProviderResponse:
 
     **NOTE** : Example values are modified for illustration purposes.
     """
-    provider_obj: LEO = init_provider(payload)
-    ai_generated_text: str = provider_obj.chat(payload.prompt)
+    provider_obj: AsyncGPT4FREE = init_provider(payload)
+    ai_generated_text: str = await provider_obj.chat(payload.prompt)
     return ProviderResponse(
         provider=(
             provider_obj.provider_name
@@ -357,10 +345,10 @@ async def non_stream(payload: TextGenerationPayload) -> ProviderResponse:
     )
 
 
-def generate_streaming_response(payload: TextGenerationPayload) -> Generator:
-    provider_obj: LEO = init_provider(payload)
-
-    for text in provider_obj.chat(payload.prompt, stream=True):
+async def generate_streaming_response(payload: TextGenerationPayload) -> Generator:
+    provider_obj = init_provider(payload)
+    async_chat = await provider_obj.chat(payload.prompt, stream=True)
+    async for text in async_chat:
         response = ProviderResponse(
             provider=(
                 provider_obj.provider_name
@@ -412,10 +400,10 @@ async def generate_image(payload: ImagePayload, request: Request) -> ImageRespon
     image_gen_obj = image_providers.get(payload.provider)(
         timeout=payload.timeout, proxies=payload.proxy
     )
-    image_generator = image_gen_obj.generate(
+    image_generator = await image_gen_obj.generate(
         prompt=payload.prompt, amount=payload.amount, stream=True
     )
-    image_urls = image_gen_obj.save(
+    image_urls = await image_gen_obj.save(
         image_generator,
         name=uuid4().__str__(),
         dir=api_static_image_dir,
@@ -441,7 +429,7 @@ async def generate_image(payload: ImageBytesPayload, request: Request) -> Respon
     image_gen_obj = image_providers.get(payload.provider)(
         timeout=payload.timeout, proxies=payload.proxy
     )
-    image_list = image_gen_obj.generate(prompt=payload.prompt)
+    image_list = await image_gen_obj.generate(prompt=payload.prompt)
     response = Response(
         image_list[0],
         media_type=f"image/{image_gen_obj.image_extension}",
@@ -474,7 +462,7 @@ async def generate_image_return_bytes(
     image_gen_obj = image_providers.get(provider, "default")(
         timeout=timeout, proxies={"https": proxy} if proxy else {}
     )
-    image_list = image_gen_obj.generate(prompt=prompt)
+    image_list = await image_gen_obj.generate(prompt=prompt)
     response = Response(
         image_list[0],
         media_type=f"image/{image_gen_obj.image_extension}",
@@ -510,7 +498,7 @@ async def text_to_audio(
     """
     host = f"{request.url.scheme}://{request.url.netloc}"
     filename = uuid4().__str__() + ".mp3"
-    Audio.text_to_audio(
+    await Audio.async_text_to_audio(
         message=payload.message,
         voice=payload.voice,
         proxies=payload.proxy,
@@ -524,7 +512,7 @@ async def text_to_audio(
 @api_exception_handler
 async def text_to_audio_bytes(
     message: str,
-    voice: str = "Brian",
+    voice: str = "en-US-Wavenet-C",
     timeout: int = 30,
     proxy: Union[str, None] = None,
 ):
@@ -537,9 +525,9 @@ async def text_to_audio_bytes(
 
     **NOTE** : *Ensure `proxy` value is correct otherwise make it `null`*
     """
-    image_bytes = Audio.text_to_audio(
+    image_bytes = await Audio.async_text_to_audio(
         message=message,
-        voice=voice if voice in Audio.all_voices else "Brian",
+        voice=voice if voice in Audio.all_voices else "en-US-Wavenet-C",
         proxies={"https": proxy} if proxy else {},
         timeout=timeout,
     )
