@@ -15,6 +15,8 @@ from typing import Union
 from typing import NoReturn
 import requests
 import vlc
+import httpx
+import asyncio
 from time import sleep as wait
 
 appdir = appdirs.AppDirs("pytgpt", "Smartwa")
@@ -33,6 +35,26 @@ os.makedirs(api_static_image_dir.as_posix(), exist_ok=True)
 os.makedirs(api_static_audio_dir.as_posix(), exist_ok=True)
 
 
+def sanitize_stream(
+    chunk: str, intro_value: str = "data:", to_json: bool = True
+) -> str | dict:
+    """Remove streaming flags
+
+    Args:
+        chunk (str): Streamig chunk.
+        intro_value (str, optional): streaming flag. Defaults to "data:".
+        to_json (bool, optional). Return chunk as dictionary. Defaults to True.
+
+    Returns:
+        str: Sanitized streaming value.
+    """
+
+    if chunk.startswith(intro_value):
+        chunk = chunk[len(intro_value) :]
+
+    return json.loads(chunk) if to_json else chunk
+
+
 def run_system_command(
     command: str,
     exit_on_error: bool = True,
@@ -152,7 +174,7 @@ class Conversation:
         """
         self.status = status
         self.max_tokens_to_sample = max_tokens
-        self.chat_history = self.intro
+        self.chat_history = ""
         self.history_format = "\nUser : %(user)s\nLLM :%(llm)s"
         self.file = filepath
         self.update_file = update_file
@@ -181,13 +203,13 @@ class Conversation:
         else:
             logging.debug(f"Loading conversation from '{filepath}'")
             with open(filepath) as fh:
-                file_contents = fh.read()
-                # Presume intro prompt is part of the file content
-                self.chat_history = file_contents
+                file_contents = fh.readlines()
+                if file_contents:
+                    self.intro = file_contents[0]  # Presume first line is the intro.
+                    self.chat_history = "\n".join(file_contents[1:])
 
-    def __trim_chat_history(self, chat_history: str, intro: str = None) -> str:
+    def __trim_chat_history(self, chat_history: str, intro: str) -> str:
         """Ensures the len(prompt) and max_tokens_to_sample is not > 4096"""
-        intro = self.intro if intro is None else intro
         len_of_intro = len(intro)
         len_of_chat_history = len(chat_history)
         total = (
@@ -196,12 +218,11 @@ class Conversation:
         if total > self.history_offset:
             truncate_at = (total - self.history_offset) + self.prompt_allowance
             # Remove head of total (n) of chat_history
-            new_chat_history = chat_history[truncate_at:]
-            self.chat_history = intro + "\n... " + new_chat_history
+            trimmed_chat_history = chat_history[truncate_at:]
+            return "... " + trimmed_chat_history
             # print(len(self.chat_history))
         else:
-            self.chat_history = intro + chat_history
-        return self.chat_history
+            return chat_history
 
     def gen_complete_prompt(self, prompt: str, intro: str = None) -> str:
         """Generates a kinda like incomplete conversation
@@ -214,8 +235,11 @@ class Conversation:
             str: Updated incomplete chat_history
         """
         if self.status:
-            resp = self.chat_history + self.history_format % dict(user=prompt, llm="")
-            return self.__trim_chat_history(resp, intro)
+            intro = self.intro if intro is None else intro
+            incomplete_chat_history = self.chat_history + self.history_format % dict(
+                user=prompt, llm=""
+            )
+            return intro + self.__trim_chat_history(incomplete_chat_history, intro)
 
         return prompt
 
@@ -233,8 +257,12 @@ class Conversation:
             return
         new_history = self.history_format % dict(user=prompt, llm=response)
         if self.file and self.update_file:
-            with open(self.file, "a") as fh:
-                fh.write(new_history)
+            if os.path.exists(self.file):
+                with open(self.file, "w") as fh:
+                    fh.write(self.intro + "\n" + new_history)
+            else:
+                with open(self.file, "a") as fh:
+                    fh.write(new_history)
         self.chat_history += new_history
 
 
@@ -887,21 +915,22 @@ class Audio:
     ]
 
     @classmethod
-    def text_to_audio(
+    async def async_text_to_audio(
         cls,
         message: str,
-        voice: str = "Brian",
+        voice: str = "en-US-Wavenet-C",
         proxies: dict[str, str] = {},
         timeout: int = 30,
         save_to: Union[Path, str] = None,
         auto: bool = False,
     ) -> Union[str, bytes]:
         """
+        Asynchronous implementation of text_to_audio.
         Text to speech using StreamElements API
 
         Parameters:
             message (str): The text to convert to speech
-            voice (str, optional): The voice to use for speech synthesis. Defaults to "Brian".
+            voice (str, optional): The voice to use for speech synthesis. Defaults to "en-US-Wavenet-C".
             proxies (dict, optional): Http request proxies. Default to {}.
             timeout (int, optional): Http request timeout. Defaults to 30.
             save_to (bool, optional): Path to save the audio file. Defaults to None.
@@ -914,15 +943,16 @@ class Audio:
             voice in cls.all_voices
         ), f"Voice '{voice}' not one of [{', '.join(cls.all_voices)}]"
         # Base URL for provider API
+        session = httpx.AsyncClient(
+            headers=cls.headers, proxies=proxies, timeout=timeout
+        )
         url: str = (
             f"https://api.streamelements.com/kappa/v2/speech?voice={voice}&text={{{message}}}"
         )
-        resp = requests.get(
-            url=url, headers=cls.headers, stream=True, proxies=proxies, timeout=timeout
-        )
-        if not resp.ok:
+        resp = await session.get(url)
+        if not resp.is_success:
             raise Exception(
-                f"Failed to perform the operation - ({resp.status_code}, {resp.reason}) - {resp.text}"
+                f"Failed to perform the operation - ({resp.status_code}, {resp.reason_phrase}) - {resp.text}"
             )
 
         def sanitize_filename(path):
@@ -951,11 +981,45 @@ class Audio:
                 save_to += ".mp3"
 
             with open(save_to, "wb") as fh:
-                for chunk in resp.iter_content(chunk_size=512):
-                    fh.write(chunk)
+                fh.write(resp.content)
+            return save_to
         else:
             return resp.content
-        return save_to
+
+    @classmethod
+    def text_to_audio(
+        cls,
+        message: str,
+        voice: str = "en-US-Wavenet-C",
+        proxies: dict[str, str] = {},
+        timeout: int = 30,
+        save_to: Union[Path, str] = None,
+        auto: bool = False,
+    ) -> Union[str, bytes]:
+        """
+        Text to speech using StreamElements API
+
+        Parameters:
+            message (str): The text to convert to speech
+            voice (str, optional): The voice to use for speech synthesis. Defaults to "en-US-Wavenet-C".
+            proxies (dict, optional): Http request proxies. Default to {}.
+            timeout (int, optional): Http request timeout. Defaults to 30.
+            save_to (bool, optional): Path to save the audio file. Defaults to None.
+            auto (bool, optional): Generate filename for the contents based on `message` and save to `cls.cache_dir`. Defaults to False.
+
+        Returns:
+            result (Union[str, bytes]): Path to saved contents or audio content.
+        """
+        return asyncio.get_event_loop().run_until_complete(
+            cls.async_text_to_audio(
+                message=message,
+                voice=voice,
+                proxies=proxies,
+                timeout=timeout,
+                save_to=save_to,
+                auto=auto,
+            )
+        )
 
     @staticmethod
     def play(path_to_audio_file: Union[Path, str]) -> NoReturn:
